from typing import Any, ClassVar, List

from typing import overload
import mrpt.pymrpt.mrpt.config
import mrpt.pymrpt.mrpt.containers
import mrpt.pymrpt.mrpt.io
import mrpt.pymrpt.mrpt.math
import mrpt.pymrpt.mrpt.rtti
import mrpt.pymrpt.mrpt.serialization
CH_GRAY: TImageChannels
CH_RGB: TImageChannels
DEEP_COPY: copy_type_t
FAST_REF_OR_CONVERT_TO_GRAY: ctor_CImage_ref_or_gray
IMG_INTERP_AREA: TInterpolationMethod
IMG_INTERP_CUBIC: TInterpolationMethod
IMG_INTERP_LINEAR: TInterpolationMethod
IMG_INTERP_NN: TInterpolationMethod
SHALLOW_COPY: copy_type_t
cmGRAYSCALE: TColormap
cmHOT: TColormap
cmJET: TColormap
cmNONE: TColormap

class CCanvas:
    class TPenStyle:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        psDash: ClassVar[CCanvas.TPenStyle] = ...
        psDashDot: ClassVar[CCanvas.TPenStyle] = ...
        psDashDotDot: ClassVar[CCanvas.TPenStyle] = ...
        psDot: ClassVar[CCanvas.TPenStyle] = ...
        psSolid: ClassVar[CCanvas.TPenStyle] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    psDash: ClassVar[CCanvas.TPenStyle] = ...
    psDashDot: ClassVar[CCanvas.TPenStyle] = ...
    psDashDotDot: ClassVar[CCanvas.TPenStyle] = ...
    psDot: ClassVar[CCanvas.TPenStyle] = ...
    psSolid: ClassVar[CCanvas.TPenStyle] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CCanvas) -> None: ...
    def assign(self) -> CCanvas: ...
    @overload
    def drawCircle(self, x: int, y: int, radius: int) -> None: ...
    @overload
    def drawCircle(self, x: int, y: int, radius: int, color: TColor) -> None: ...
    @overload
    def drawCircle(self, x: int, y: int, radius: int, color: TColor, width: int) -> None: ...
    @overload
    def drawImage(self, x: int, y: int, img) -> None: ...
    @overload
    def drawImage(self, x: int, y: int, img, rotation: float, scale: float) -> None: ...
    @overload
    def drawMark(self, x0: int, y0: int, color: TColor, type: str) -> None: ...
    @overload
    def drawMark(self, x0: int, y0: int, color: TColor, type: str, size: int) -> None: ...
    @overload
    def drawMark(self, x0: int, y0: int, color: TColor, type: str, size: int, width: int) -> None: ...
    def ellipseGaussian(self, *args, **kwargs) -> Any: ...
    def filledRectangle(self, x0: int, y0: int, x1: int, y1: int, color: TColor) -> None: ...
    @overload
    def getHeight(self) -> int: ...
    @overload
    def getHeight() -> size_t: ...
    @overload
    def getWidth(self) -> int: ...
    @overload
    def getWidth() -> size_t: ...
    @overload
    def line(self, x0: int, y0: int, x1: int, y1: int, color: TColor) -> None: ...
    @overload
    def line(self, x0: int, y0: int, x1: int, y1: int, color: TColor, width: int) -> None: ...
    @overload
    def line(self, x0: int, y0: int, x1: int, y1: int, color: TColor, width: int, penStyle: CCanvas.TPenStyle) -> None: ...
    @overload
    def rectangle(self, x0: int, y0: int, x1: int, y1: int, color: TColor) -> None: ...
    @overload
    def rectangle(self, x0: int, y0: int, x1: int, y1: int, color: TColor, width: int) -> None: ...
    @overload
    def rectangle(anemptyrectangle, withoutfilling) -> Any: ...
    @overload
    def selectTextFont(self, fontName: str) -> None: ...
    @overload
    def selectTextFont(conststd) -> void: ...
    def setPixel(self, *args, **kwargs) -> Any: ...
    def textOut(self, x0: int, y0: int, str: str, color: TColor) -> None: ...
    @overload
    def triangle(self, x0: int, y0: int, size: int, color: TColor) -> None: ...
    @overload
    def triangle(self, x0: int, y0: int, size: int, color: TColor, inferior: bool) -> None: ...
    @overload
    def triangle(self, x0: int, y0: int, size: int, color: TColor, inferior: bool, width: int) -> None: ...

class CExceptionExternalImageNotFound:
    @overload
    def __init__(self, s: str) -> None: ...
    @overload
    def __init__(self, arg0: CExceptionExternalImageNotFound) -> None: ...
    @overload
    def __init__(self, arg0: CExceptionExternalImageNotFound) -> None: ...
    def assign(self) -> CExceptionExternalImageNotFound: ...

class CImage(mrpt.pymrpt.mrpt.serialization.CSerializable, CCanvas):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __init__(self, width: int, height: int, nChannels: TImageChannels) -> None: ...
    @overload
    def __init__(self, other_img: CImage) -> None: ...
    @overload
    def __init__(self, img: CImage, copy_type: copy_type_t) -> None: ...
    @overload
    def __init__(self, arg0: CImage) -> None: ...
    @overload
    def __init__(self, arg0: CImage) -> None: ...
    def CreateObject(self, *args, **kwargs) -> Any: ...
    def DISABLE_JPEG_COMPRESSION(self, *args, **kwargs) -> Any: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    @overload
    def KLT_response(self, x: int, y: int, half_window_size: int) -> float: ...
    @overload
    def KLT_response() -> Any: ...
    def LoadFromFile(self, *args, **kwargs) -> Any: ...
    def SERIALIZATION_JPEG_QUALITY(self, *args, **kwargs) -> Any: ...
    def assign(self) -> CImage: ...
    @overload
    def channelCount(self) -> int: ...
    @overload
    def channelCount() -> int: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def clone(self) -> mrpt.pymrpt.mrpt.rtti.CObject: ...
    @overload
    def colorImage(self) -> CImage: ...
    @overload
    def colorImage(self, ret: CImage) -> None: ...
    @overload
    def colorImage(classmrpt) -> void: ...
    @overload
    def copyFromForceLoad(self, o: CImage) -> None: ...
    @overload
    def copyFromForceLoad(constclassmrpt) -> void: ...
    def correlate(self, *args, **kwargs) -> Any: ...
    def cross_correlation_FFT(self, *args, **kwargs) -> Any: ...
    @overload
    def drawCircle(self, x: int, y: int, radius: int) -> None: ...
    @overload
    def drawCircle(self, x: int, y: int, radius: int, color: TColor) -> None: ...
    @overload
    def drawCircle(self, x: int, y: int, radius: int, color: TColor, width: int) -> None: ...
    def drawImage(self, x: int, y: int, img: CImage) -> None: ...
    @overload
    def equalizeHist(self, out_img: CImage) -> None: ...
    @overload
    def equalizeHist(classmrpt) -> void: ...
    def extract_patch(self, *args, **kwargs) -> Any: ...
    def filledRectangle(self, x0: int, y0: int, x1: int, y1: int, color: TColor) -> None: ...
    @overload
    def filterGaussian(self, out_img: CImage) -> None: ...
    @overload
    def filterGaussian(self, out_img: CImage, W: int) -> None: ...
    @overload
    def filterGaussian(self, out_img: CImage, W: int, H: int) -> None: ...
    @overload
    def filterGaussian(self, out_img: CImage, W: int, H: int, sigma: float) -> None: ...
    @overload
    def filterMedian(self, out_img: CImage) -> None: ...
    @overload
    def filterMedian(self, out_img: CImage, W: int) -> None: ...
    @overload
    def filterMedian(classmrpt, int) -> void: ...
    @overload
    def flipHorizontal(self) -> None: ...
    @overload
    def flipHorizontal() -> void: ...
    @overload
    def flipVertical(self) -> None: ...
    @overload
    def flipVertical() -> void: ...
    @overload
    def forceLoad(self) -> None: ...
    @overload
    def forceLoad() -> void: ...
    @overload
    def getAsFloat(self, col: int, row: int, channel: int) -> float: ...
    @overload
    def getAsFloat(self, col: int, row: int) -> float: ...
    def getAsMatrix(self, *args, **kwargs) -> Any: ...
    def getAsMatrixTiled(self, *args, **kwargs) -> Any: ...
    def getAsRGBMatrices(self, *args, **kwargs) -> Any: ...
    def getChannelCount(self) -> TImageChannels: ...
    def getChannelsOrder(self) -> str: ...
    def getExternalStorageFile(self) -> str: ...
    @overload
    def getExternalStorageFileAbsolutePath(self, out_path: str) -> None: ...
    @overload
    def getExternalStorageFileAbsolutePath(std) -> void: ...
    @overload
    def getExternalStorageFileAbsolutePath(self) -> str: ...
    @overload
    def getHeight(self) -> int: ...
    @overload
    def getHeight() -> size_t: ...
    def getImagesPathBase(self, *args, **kwargs) -> Any: ...
    @overload
    def getMaxAsFloat(self) -> float: ...
    @overload
    def getMaxAsFloat() -> float: ...
    def getPixelDepth(self) -> PixelDepth: ...
    @overload
    def getRowStride(self) -> int: ...
    @overload
    def getRowStride() -> size_t: ...
    @overload
    def getSize(self, s: TPixelCoord) -> None: ...
    @overload
    def getSize(structmrpt) -> void: ...
    @overload
    def getSize(self) -> TPixelCoord: ...
    @overload
    def getWidth(self) -> int: ...
    @overload
    def getWidth() -> size_t: ...
    @overload
    def grayscale(self) -> CImage: ...
    @overload
    def grayscale(self, ret: CImage) -> bool: ...
    @overload
    def grayscale(classmrpt) -> bool: ...
    @overload
    def isColor(self) -> bool: ...
    @overload
    def isColor() -> bool: ...
    @overload
    def isEmpty(self) -> bool: ...
    @overload
    def isEmpty() -> bool: ...
    @overload
    def isExternallyStored(self) -> bool: ...
    @overload
    def isExternallyStored() -> bool: ...
    @overload
    def isOriginTopLeft(self) -> bool: ...
    @overload
    def isOriginTopLeft() -> bool: ...
    def joinImagesHorz(self, im1: CImage, im2: CImage) -> None: ...
    @overload
    def line(self, x0: int, y0: int, x1: int, y1: int, color: TColor) -> None: ...
    @overload
    def line(self, x0: int, y0: int, x1: int, y1: int, color: TColor, width: int) -> None: ...
    @overload
    def line(self, x0: int, y0: int, x1: int, y1: int, color: TColor, width: int, penStyle: CCanvas.TPenStyle) -> None: ...
    @overload
    def loadFromFile(self, fileName: str) -> bool: ...
    @overload
    def loadFromFile(self, fileName: str, isColor: int) -> bool: ...
    @overload
    def loadFromFile(conststd, int) -> bool: ...
    @overload
    def loadFromMemoryBuffer(self, width: int, height: int, color: bool, rawpixels: int) -> None: ...
    @overload
    def loadFromMemoryBuffer(self, width: int, height: int, color: bool, rawpixels: int, swapRedBlue: bool) -> None: ...
    @overload
    def loadFromMemoryBuffer(self, width: int, height: int, bytesPerRow: int, red: int, green: int, blue: int) -> None: ...
    @overload
    def loadFromStreamAsJPEG(self, in: mrpt.pymrpt.mrpt.io.CStream) -> None: ...
    @overload
    def loadFromStreamAsJPEG(classmrpt) -> void: ...
    def loadTGA(self, *args, **kwargs) -> Any: ...
    def makeDeepCopy(self) -> CImage: ...
    def makeShallowCopy(self) -> CImage: ...
    @overload
    def normalize(self) -> None: ...
    @overload
    def normalize() -> void: ...
    @overload
    def ptrLine(self, row: int) -> int: ...
    @overload
    def ptrLine(self, row: int) -> int: ...
    def rectifyImageInPlace(self, mapX: capsule, mapY: capsule) -> None: ...
    def resize(self, *args, **kwargs) -> Any: ...
    @overload
    def rotateImage(self, out_img: CImage, ang: float, cx: int, cy: int) -> None: ...
    @overload
    def rotateImage(self, out_img: CImage, ang: float, cx: int, cy: int, scale: float) -> None: ...
    @overload
    def saveToFile(self, fileName: str) -> bool: ...
    @overload
    def saveToFile(self, fileName: str, jpeg_quality: int) -> bool: ...
    @overload
    def saveToFile(conststd, int) -> bool: ...
    @overload
    def saveToStreamAsJPEG(self, out: mrpt.pymrpt.mrpt.io.CStream) -> None: ...
    @overload
    def saveToStreamAsJPEG(self, out: mrpt.pymrpt.mrpt.io.CStream, jpeg_quality: int) -> None: ...
    @overload
    def saveToStreamAsJPEG(classmrpt, constint) -> void: ...
    @overload
    def scaleDouble(self, interp: TInterpolationMethod) -> CImage: ...
    @overload
    def scaleDouble(self, out_image: CImage, interp: TInterpolationMethod) -> None: ...
    @overload
    def scaleDouble(classmrpt, enummrpt) -> void: ...
    @overload
    def scaleHalf(self, interp: TInterpolationMethod) -> CImage: ...
    @overload
    def scaleHalf(self, out_image: CImage, interp: TInterpolationMethod) -> bool: ...
    @overload
    def scaleHalf(classmrpt, enummrpt) -> bool: ...
    @overload
    def scaleImage(self, out_img: CImage, width: int, height: int) -> None: ...
    @overload
    def scaleImage(self, out_img: CImage, width: int, height: int, interp: TInterpolationMethod) -> None: ...
    @overload
    def setExternalStorage(self, fileName: str) -> None: ...
    @overload
    def setExternalStorage(conststd) -> void: ...
    def setImagesPathBase(self, *args, **kwargs) -> Any: ...
    def setPixel(self, *args, **kwargs) -> Any: ...
    @overload
    def swap(self, o: CImage) -> None: ...
    @overload
    def swap(classmrpt) -> void: ...
    @overload
    def swapRB(self) -> None: ...
    @overload
    def swapRB() -> void: ...
    @overload
    def undistort(self, out_img: CImage, cameraParams: TCamera) -> None: ...
    @overload
    def undistort(classmrpt, constclassmrpt) -> void: ...
    @overload
    def unload(self) -> None: ...
    @overload
    def unload() -> void: ...
    def update_patch(self, patch: CImage, col: int, row: int) -> None: ...
    def __call__(self, *args, **kwargs) -> Any: ...

class DistortionModel:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    kannala_brandt: ClassVar[DistortionModel] = ...
    none: ClassVar[DistortionModel] = ...
    plumb_bob: ClassVar[DistortionModel] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class PixelDepth:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    D16S: ClassVar[PixelDepth] = ...
    D16U: ClassVar[PixelDepth] = ...
    D32F: ClassVar[PixelDepth] = ...
    D32S: ClassVar[PixelDepth] = ...
    D64F: ClassVar[PixelDepth] = ...
    D8S: ClassVar[PixelDepth] = ...
    D8U: ClassVar[PixelDepth] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TCamera(mrpt.pymrpt.mrpt.serialization.CSerializable):
    cameraName: str
    dist: List[float[8]]
    distortion: DistortionModel
    focalLengthMeters: float
    intrinsicParams: Any
    ncols: int
    nrows: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TCamera) -> None: ...
    @overload
    def __init__(self, arg0: TCamera) -> None: ...
    def CreateObject(self, *args, **kwargs) -> Any: ...
    def FromYAML(self, *args, **kwargs) -> Any: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def asYAML(self) -> mrpt.pymrpt.mrpt.containers.yaml: ...
    def assign(self) -> TCamera: ...
    def clone(self) -> mrpt.pymrpt.mrpt.rtti.CObject: ...
    @overload
    def cx(self) -> float: ...
    @overload
    def cx() -> double: ...
    @overload
    def cx(self, val: float) -> None: ...
    @overload
    def cx(double) -> void: ...
    @overload
    def cy(self) -> float: ...
    @overload
    def cy() -> double: ...
    @overload
    def cy(self, val: float) -> None: ...
    @overload
    def cy(double) -> void: ...
    def dumpAsText(self) -> str: ...
    @overload
    def fx(self) -> float: ...
    @overload
    def fx() -> double: ...
    @overload
    def fx(self, val: float) -> None: ...
    @overload
    def fx(double) -> void: ...
    @overload
    def fy(self) -> float: ...
    @overload
    def fy() -> double: ...
    @overload
    def fy(self, val: float) -> None: ...
    @overload
    def fy(double) -> void: ...
    def getDistortionParamsAsRowVector(self, *args, **kwargs) -> Any: ...
    @overload
    def k1(self) -> float: ...
    @overload
    def k1() -> double: ...
    @overload
    def k1(self, val: float) -> None: ...
    @overload
    def k1(double) -> void: ...
    @overload
    def k2(self) -> float: ...
    @overload
    def k2() -> double: ...
    @overload
    def k2(self, val: float) -> None: ...
    @overload
    def k2(double) -> void: ...
    @overload
    def k3(self) -> float: ...
    @overload
    def k3() -> double: ...
    @overload
    def k3(self, val: float) -> None: ...
    @overload
    def k3(double) -> void: ...
    @overload
    def k4(self) -> float: ...
    @overload
    def k4() -> double: ...
    @overload
    def k4(self, val: float) -> None: ...
    @overload
    def k4(double) -> void: ...
    @overload
    def k5(self) -> float: ...
    @overload
    def k5() -> double: ...
    @overload
    def k5(self, val: float) -> None: ...
    @overload
    def k5(double) -> void: ...
    @overload
    def k6(self) -> float: ...
    @overload
    def k6() -> double: ...
    @overload
    def k6(self, val: float) -> None: ...
    @overload
    def k6(double) -> void: ...
    @overload
    def loadFromConfigFile(self, section: str, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase) -> None: ...
    @overload
    def loadFromConfigFile(conststd, constclassmrpt) -> void: ...
    @overload
    def loadFromConfigFile(self, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    @overload
    def p1(self) -> float: ...
    @overload
    def p1() -> double: ...
    @overload
    def p1(self, val: float) -> None: ...
    @overload
    def p1(double) -> void: ...
    @overload
    def p2(self) -> float: ...
    @overload
    def p2() -> double: ...
    @overload
    def p2(self, val: float) -> None: ...
    @overload
    def p2(double) -> void: ...
    @overload
    def saveToConfigFile(self, section: str, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase) -> None: ...
    @overload
    def saveToConfigFile(conststd, classmrpt) -> void: ...
    def scaleToResolution(self, new_ncols: int, new_nrows: int) -> None: ...
    def setDistortionKannalaBrandt(self, k1_: float, k2_: float, k3_: float, k4_: float) -> None: ...
    @overload
    def setDistortionPlumbBob(self, k1_: float, k2_: float, p1_: float, p2_: float) -> None: ...
    @overload
    def setDistortionPlumbBob(self, k1_: float, k2_: float, p1_: float, p2_: float, k3_: float) -> None: ...
    def setIntrinsicParamsFromValues(self, fx: float, fy: float, cx: float, cy: float) -> None: ...

class TColor:
    A: int
    B: int
    G: int
    R: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, r: int, g: int, b: int) -> None: ...
    @overload
    def __init__(self, r: int, g: int, b: int, alpha: int) -> None: ...
    @overload
    def __init__(self, color_RGB_24bit: int) -> None: ...
    @overload
    def __init__(self, color_RGB_24bit: int, alpha: int) -> None: ...
    @overload
    def __init__(self, arg0: TColor) -> None: ...
    def assign(self, other: TColor) -> TColor: ...
    def black(self, *args, **kwargs) -> Any: ...
    def blue(self, *args, **kwargs) -> Any: ...
    def gray(self, *args, **kwargs) -> Any: ...
    def green(self, *args, **kwargs) -> Any: ...
    def red(self, *args, **kwargs) -> Any: ...
    def white(self, *args, **kwargs) -> Any: ...
    def __iadd__(self, other: TColor) -> TColor: ...
    def __isub__(self, other: TColor) -> TColor: ...

class TColorf:
    A: float
    B: float
    G: float
    R: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, r: float, g: float, b: float) -> None: ...
    @overload
    def __init__(self, r: float, g: float, b: float, alpha: float) -> None: ...
    @overload
    def __init__(self, col: TColor) -> None: ...
    @overload
    def __init__(self, arg0: TColorf) -> None: ...
    def asTColor(self) -> TColor: ...
    def assign(self) -> TColorf: ...

class TColormap:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    cmGRAYSCALE: ClassVar[TColormap] = ...
    cmHOT: ClassVar[TColormap] = ...
    cmJET: ClassVar[TColormap] = ...
    cmNONE: ClassVar[TColormap] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TImageChannels:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    CH_GRAY: ClassVar[TImageChannels] = ...
    CH_RGB: ClassVar[TImageChannels] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TInterpolationMethod:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    IMG_INTERP_AREA: ClassVar[TInterpolationMethod] = ...
    IMG_INTERP_CUBIC: ClassVar[TInterpolationMethod] = ...
    IMG_INTERP_LINEAR: ClassVar[TInterpolationMethod] = ...
    IMG_INTERP_NN: ClassVar[TInterpolationMethod] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TPixelCoord:
    __hash__: ClassVar[None] = ...
    x: int
    y: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, _x: int, _y: int) -> None: ...
    @overload
    def __init__(self, arg0: TPixelCoord) -> None: ...
    def assign(self) -> TPixelCoord: ...
    def __eq__(self, o: TPixelCoord) -> bool: ...

class TPixelCoordf:
    x: float
    y: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, _x: float, _y: float) -> None: ...
    @overload
    def __init__(self, arg0: TPixelCoordf) -> None: ...
    def assign(self) -> TPixelCoordf: ...

class TStereoCamera(mrpt.pymrpt.mrpt.serialization.CSerializable):
    leftCamera: TCamera
    rightCamera: TCamera
    rightCameraPose: mrpt.pymrpt.mrpt.math.TPose3DQuat
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TStereoCamera) -> None: ...
    @overload
    def __init__(self, arg0: TStereoCamera) -> None: ...
    def CreateObject(self, *args, **kwargs) -> Any: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def assign(self) -> TStereoCamera: ...
    def clone(self) -> mrpt.pymrpt.mrpt.rtti.CObject: ...
    def dumpAsText(self) -> str: ...
    @overload
    def loadFromConfigFile(self, section: str, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase) -> None: ...
    @overload
    def loadFromConfigFile(conststd, constclassmrpt) -> void: ...
    @overload
    def loadFromConfigFile(self, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    def saveToConfigFile(self, *args, **kwargs) -> Any: ...
    def scaleToResolution(self, new_ncols: int, new_nrows: int) -> None: ...

class copy_type_t:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    DEEP_COPY: ClassVar[copy_type_t] = ...
    SHALLOW_COPY: ClassVar[copy_type_t] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ctor_CImage_ref_or_gray:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    FAST_REF_OR_CONVERT_TO_GRAY: ClassVar[ctor_CImage_ref_or_gray] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

@overload
def colormap(color_map: TColormap, color_index: float, r: float, g: float, b: float) -> None: ...
@overload
def colormap(color_map: TColormap, color_index: float) -> TColor: ...
def hot2rgb(color_index: float, r: float, g: float, b: float) -> None: ...
def hsv2rgb(h: float, s: float, v: float, r: float, g: float, b: float) -> None: ...
def jet2rgb(color_index: float, r: float, g: float, b: float) -> None: ...
def rgb2hsv(r: float, g: float, b: float, h: float, s: float, v: float) -> None: ...



#!/usr/bin/env python3

# ---------------------------------------------------------------------
# Install python3-pymrpt, ros-$ROS_DISTRO-python-mrpt,
# ros-$ROS_DISTRO-mrpt2, or test with a local build with:
# export PYTHONPATH=$HOME/code/mrpt/build-Release/:$PYTHONPATH
# ---------------------------------------------------------------------

# RBPF-SLAM: builds a gridmap from a 2D lidar dataset.
#
# Usage example:
#
# ./rbpf_slam.py --help
#
# ./rbpf_slam.py -c ../share/mrpt/config_files/rbpf-slam/gridmapping_optimal_sampling.ini  ../share/mrpt/datasets/2006-01ENE-21-SENA_Telecom\ Faculty_one_loop_only.rawlog
#

from mrpt.pymrpt import mrpt
import argparse

# args
parser = argparse.ArgumentParser()
parser.add_argument('rawlog', help='Rawlog file.')
parser.add_argument('-c', '--config', help='Config file.')
parser.add_argument(
    '-o', '--output', help='Save final map as to file with this prefix name.', default='final_map')
args = parser.parse_args()

# get filenames from args
rawlog_filename = args.rawlog
config_filename = args.config
output_filename = args.output

# Instance SLAM app, init, and run SLAM:
app = mrpt.apps.RBPF_SLAM_App_Rawlog()

app.init(iniConfigFile=config_filename, rawlogFile=rawlog_filename)

app.run()

# Get last built map
app.mapBuilder.saveCurrentMapToFile('final_map.simplemap')

# Save map:
print('saving final map to: "{}_*"'.format(output_filename))

metricMap = app.mapBuilder.getCurrentlyBuiltMetricMap()
metricMap.saveMetricMapRepresentationToFile(output_filename)



from typing import overload
import mrpt.pymrpt.mrpt.io

def compress(inData: capsule, inDataSize: int, out: mrpt.pymrpt.mrpt.io.CStream) -> None: ...
@overload
def decompress(inData: capsule, inDataSize: int, outData: capsule, outDataBufferSize: int) -> int: ...
@overload
def decompress(inStream: mrpt.pymrpt.mrpt.io.CStream, inDataSize: int, outData: capsule, outDataBufferSize: int) -> int: ...



#!/usr/bin/env python3

from math import radians
from mrpt.pymrpt.mrpt.poses import CPose2D
from mrpt.pymrpt.mrpt.math import TPose2D
import os

print('[Running python test ' + os.path.basename(__file__) + ']')

p1 = CPose2D(1.0, 2.0, radians(90.0))
p2 = CPose2D(3.0, 0.0, radians(0.0))

p3 = p1 + p2
p4 = p3 - p1

assert ((p4-p2).norm() < 1e-4)
assert (abs(p4.phi()-p2.phi()) < 1e-4)

p4t: TPose2D = p4.asTPose()
assert (abs(p4t.x - p4.x()) < 1e-8)
assert (abs(p4t.y - p4.y()) < 1e-8)
assert (abs(p4t.phi - p4.phi()) < 1e-8)

print('[Successfully run ' + os.path.basename(__file__) + ']')



from typing import ClassVar

CDGPS: nv_position_type_t
DOPPLER_VELOCITY: nv_position_type_t
FIXEDHEIGHT: nv_position_type_t
FIXEDPOS: nv_position_type_t
FLOATCONV: nv_position_type_t
INS: nv_position_type_t
INS_PSRDIFF: nv_position_type_t
INS_PSRSP: nv_position_type_t
INS_RTKFIXED: nv_position_type_t
INS_RTKFLOAT: nv_position_type_t
IONOFREE_FLOAT: nv_position_type_t
L1_FLOAT: nv_position_type_t
L1_INT: nv_position_type_t
NARROWLANE: nv_position_type_t
NARROW_FLOAT: nv_position_type_t
NARROW_INT: nv_position_type_t
NONE: nv_position_type_t
OMNISTAR: nv_position_type_t
OMNISTAR_HP: nv_position_type_t
OMNISTAR_XP: nv_position_type_t
PROPAGATED: nv_position_type_t
PSRDIFF: nv_position_type_t
RTK_DIRECT_INS: nv_position_type_t
Reserved: nv_position_type_t
SINGLE: nv_position_type_t
WAAS: nv_position_type_t
WIDELANE: nv_position_type_t
WIDE_INT: nv_position_type_t

class nv_position_type_t:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    CDGPS: ClassVar[nv_position_type_t] = ...
    DOPPLER_VELOCITY: ClassVar[nv_position_type_t] = ...
    FIXEDHEIGHT: ClassVar[nv_position_type_t] = ...
    FIXEDPOS: ClassVar[nv_position_type_t] = ...
    FLOATCONV: ClassVar[nv_position_type_t] = ...
    INS: ClassVar[nv_position_type_t] = ...
    INS_PSRDIFF: ClassVar[nv_position_type_t] = ...
    INS_PSRSP: ClassVar[nv_position_type_t] = ...
    INS_RTKFIXED: ClassVar[nv_position_type_t] = ...
    INS_RTKFLOAT: ClassVar[nv_position_type_t] = ...
    IONOFREE_FLOAT: ClassVar[nv_position_type_t] = ...
    L1_FLOAT: ClassVar[nv_position_type_t] = ...
    L1_INT: ClassVar[nv_position_type_t] = ...
    NARROWLANE: ClassVar[nv_position_type_t] = ...
    NARROW_FLOAT: ClassVar[nv_position_type_t] = ...
    NARROW_INT: ClassVar[nv_position_type_t] = ...
    NONE: ClassVar[nv_position_type_t] = ...
    OMNISTAR: ClassVar[nv_position_type_t] = ...
    OMNISTAR_HP: ClassVar[nv_position_type_t] = ...
    OMNISTAR_XP: ClassVar[nv_position_type_t] = ...
    PROPAGATED: ClassVar[nv_position_type_t] = ...
    PSRDIFF: ClassVar[nv_position_type_t] = ...
    RTK_DIRECT_INS: ClassVar[nv_position_type_t] = ...
    Reserved: ClassVar[nv_position_type_t] = ...
    SINGLE: ClassVar[nv_position_type_t] = ...
    WAAS: ClassVar[nv_position_type_t] = ...
    WIDELANE: ClassVar[nv_position_type_t] = ...
    WIDE_INT: ClassVar[nv_position_type_t] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

def enum2str(val: int) -> str: ...



#!/usr/bin/env python3

# ---------------------------------------------------------------------
# Install python3-pymrpt, ros-$ROS_DISTRO-python-mrpt,
# ros-$ROS_DISTRO-mrpt2, or test with a local build with:
# export PYTHONPATH=$HOME/code/mrpt/build-Release/:$PYTHONPATH
# ---------------------------------------------------------------------

#
# Usage example:
#
# ./global_localization.py ../share/mrpt/config_files/pf-localization/localization_demo.ini
#
from mrpt.pymrpt import mrpt
import os
import sys
import argparse
from time import sleep


# args
parser = argparse.ArgumentParser()
parser.add_argument('config', help='Config file.')
parser.add_argument(
    '-d', '--delay', help='Time delay in seconds. Default: 0.2')
parser.add_argument('-r', '--resolution',
                    help='Window resolution. Default: 800x600')
args = parser.parse_args()

# get filenames from args
config_filename = args.config

# get configuration
if not os.path.exists(config_filename):
    print('Error. Config file not found.')
    print('Quit.')
    sys.exit(1)

config_file = mrpt.config.CConfigFile(config_filename)
print('Load config file {}.'.format(config_filename))
sec_name = 'LocalizationExperiment'

rawlog_filename = config_file.read_string(sec_name, "rawlog_file", "")
map_filename = config_file.read_string(sec_name, "map_file", "")


# default filenames are relative so we need to change our dir to supplied config file dir
curr_dir = os.path.abspath(os.curdir)
config_dir = os.path.dirname(os.path.abspath(config_filename))
# rawlog
if not os.path.exists(os.path.abspath(rawlog_filename)):
    os.chdir(config_dir)
    if not os.path.exists(os.path.abspath(rawlog_filename)):
        print('Error. Rawlog file not found.')
        print('Quit.')
        sys.exit(1)
    else:
        rawlog_filename = os.path.abspath(rawlog_filename)
        os.chdir(curr_dir)
rawlog_file = mrpt.io.CFileGZInputStream(rawlog_filename)
print('Load rawlog file {}.'.format(rawlog_filename))

# map
if not os.path.exists(os.path.abspath(map_filename)):
    os.chdir(config_dir)
    if not os.path.exists(os.path.abspath(map_filename)):
        print('Error. Map file not found.')
        print('Quit.')
        sys.exit(1)
    else:
        map_filename = os.path.abspath(map_filename)
        os.chdir(curr_dir)

# Load parameters:
# KLD (Adapative sampling)
pdf_prediction_options = mrpt.slam.TMonteCarloLocalizationParams()
pdf_prediction_options.KLD_params.loadFromConfigFileName(
    config_filename, 'KLD_options')
pdf_prediction_options.KLD_params.dumpToConsole()

# Particle filtering itself:
pf_options = mrpt.bayes.CParticleFilter.TParticleFilterOptions()
pf_options.loadFromConfigFileName(config_filename, 'PF_options')
pf_options.dumpToConsole()

# Metric maps to build:
map_list = mrpt.maps.TSetOfMetricMapInitializers()
map_list.loadFromConfigFileName(config_filename, 'MetricMap')
map_list.dumpToConsole()

# setup
metric_map = mrpt.maps.CMultiMetricMap()
metric_map.setListOfMaps(map_list)

# load map
map_file = mrpt.io.CFileGZInputStream(map_filename)
map_arch = mrpt.serialization.archiveFrom(map_file)

if (map_filename.endswith('.simplemap')
        or map_filename.endswith('.simplemap.gz')):
    simple_map = mrpt.maps.CSimpleMap()
    map_arch.ReadObject(simple_map)
    metric_map.loadFromProbabilisticPosesAndObservations(simple_map)
elif (map_filename.endswith('.gridmap')
        or map_filename.endswith('.gridmap.gz')):
    occ_map = mrpt.maps.COccupancyGridMap2D()
    map_arch.ReadObject(occ_map)
    # overwrite gridmap
    for i in range(len(metric_map.maps)):
        if metric_map.maps[i].GetRuntimeClass().className == 'COccupancyGridMap2D':
            metric_map.maps[i] = occ_map
else:
    print('Error. Can not load map from unknown extension.')
    print('Quit.')
    sys.exit(1)
print('Load map file {}.'.format(map_filename))

# get window resolution
if args.resolution:
    resolution_str = args.resolution
else:
    resolution_str = '800x600'

# gui
try:
    res = resolution_str.split('x')
    win3D = mrpt.gui.CDisplayWindow3D(
        "pf_localization", int(res[0]), int(res[1]))
except:
    win3D = mrpt.gui.CDisplayWindow3D("pf_localization", 800, 600)

# initial scene
map_object = metric_map.getVisualization()

scene_ptr = win3D.get3DSceneAndLock()
scene_ptr.clear()
scene_ptr.insert(map_object)
win3D.unlockAccess3DScene()
win3D.forceRepaint()

# mcl
pdf = mrpt.slam.CMonteCarloLocalization2D()
pdf.options = pdf_prediction_options
pdf.options.metricMap = metric_map

pf = mrpt.bayes.CParticleFilter()
pf.m_options = pf_options

# initialize pdf
pdf.resetUniformFreeSpace(metric_map.maps[0], 0.7, 40000)

# Archive for reading from the file:
rawlogArch = mrpt.serialization.archiveFrom(rawlog_file)

# loop
entry = 0
while True:
    # get action observation pair
    [readOk, entry, act, sf, obs] = mrpt.obs.CRawlog.ReadFromArchive(
        rawlogArch, entry)
    if not readOk:
        break

    print('Processing entry: {}.'.format(entry))

    # get covariance and mean
    cov, mean = pdf.getCovarianceAndMean()

    # get particles
    particles_object = pdf.getVisualization()

    # get visualization for laser scan (two ways for demonstration purposes)
    if False:
        # Alternative method 1:
        # Insert the observations into a point cloud:
        points_map = mrpt.maps.CSimplePointsMap()
        points_map.insertObs(sf)

        # And get the visualization of the point cloud:
        glObservation = points_map.getVisualization()
    else:
        # Alternative 2:
        # Using the generic obs_to_viz() method:
        vizOpts = mrpt.obs.VisualizationParameters()
        vizOpts.pointSize = 3
        vizOpts.showAxis = False

        glObservation = mrpt.opengl.CSetOfObjects()

        mrpt.obs.obs_to_viz(sf, vizOpts, glObservation)

    glObservation.setPose(mrpt.poses.CPose3D(mean))
    glObservation.setColor(mrpt.img.TColorf(1., 0., 0.))

    # update pf
    stats = pf.executeOn(pdf, act, sf)

    # update scene
    scene_ptr = win3D.get3DSceneAndLock()
    scene_ptr.clear()
    scene_ptr.insert(map_object)
    scene_ptr.insert(particles_object)
    scene_ptr.insert(glObservation)
    win3D.unlockAccess3DScene()
    win3D.forceRepaint()

    # sleep
    if args.delay:
        try:
            sleep(float(args.delay))
        except:
            sleep(0.2)
    else:
        sleep(0.2)

print()
print('Done.')
input('Press any key to quit.')



from typing import Any

def BumblebeeCamera(*args, **kwargs) -> Any: ...
def CornerXYSimple(*args, **kwargs) -> Any: ...
def CornerXYZ(*args, **kwargs) -> Any: ...
def CornerXYZEye(*args, **kwargs) -> Any: ...
def CornerXYZSimple(*args, **kwargs) -> Any: ...
def Hokuyo_URG(*args, **kwargs) -> Any: ...
def Hokuyo_UTM(*args, **kwargs) -> Any: ...
def Househam_Sprayer(*args, **kwargs) -> Any: ...
def RobotGiraff(*args, **kwargs) -> Any: ...
def RobotPioneer(*args, **kwargs) -> Any: ...
def RobotRhodon(*args, **kwargs) -> Any: ...



from typing import Any

class EuclideanBase_2U_t:
    def __init__(self) -> None: ...

class EuclideanBase_3U_t:
    def __init__(self) -> None: ...

class Euclidean_2U_t(EuclideanBase_2U_t):
    def __init__(self) -> None: ...

class Euclidean_3U_t(EuclideanBase_3U_t):
    def __init__(self) -> None: ...

class SE_2U_t:
    def __init__(self) -> None: ...
    def asManifoldVector(self, *args, **kwargs) -> Any: ...
    def exp(self, *args, **kwargs) -> Any: ...
    def fromManifoldVector(self, *args, **kwargs) -> Any: ...
    def jacob_dAB_dA(self, *args, **kwargs) -> Any: ...
    def jacob_dAB_dB(self, *args, **kwargs) -> Any: ...
    def jacob_dDexpe_de(self, *args, **kwargs) -> Any: ...
    def log(self, *args, **kwargs) -> Any: ...

class SE_3U_t:
    def __init__(self) -> None: ...
    def asManifoldVector(self, *args, **kwargs) -> Any: ...
    def exp(self, *args, **kwargs) -> Any: ...
    def fromManifoldVector(self, *args, **kwargs) -> Any: ...
    def log(self, *args, **kwargs) -> Any: ...

class SO_2U_t:
    def __init__(self) -> None: ...

class SO_3U_t:
    def __init__(self) -> None: ...
    def exp(self, *args, **kwargs) -> Any: ...
    def fromYPR(self, *args, **kwargs) -> Any: ...
    def log(self, *args, **kwargs) -> Any: ...
    def vee_RmRt(self, *args, **kwargs) -> Any: ...



from typing import Any, ClassVar, List

from typing import overload
import mrpt.pymrpt.std.chrono
LVL_DEBUG: VerbosityLevel
LVL_ERROR: VerbosityLevel
LVL_INFO: VerbosityLevel
LVL_WARN: VerbosityLevel
NUMBER_OF_VERBOSITY_LEVELS: VerbosityLevel
ppHigh: TProcessPriority
ppIdle: TProcessPriority
ppNormal: TProcessPriority
ppVeryHigh: TProcessPriority
tpHigh: TThreadPriority
tpHigher: TThreadPriority
tpHighest: TThreadPriority
tpLow: TThreadPriority
tpLower: TThreadPriority
tpLowests: TThreadPriority
tpNormal: TThreadPriority

class CControlledRateTimer:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, rate_hz: float) -> None: ...
    @overload
    def __init__(self, arg0: CControlledRateTimer) -> None: ...
    @overload
    def actualControlledRate(self) -> float: ...
    @overload
    def actualControlledRate() -> double: ...
    def assign(self) -> CControlledRateTimer: ...
    @overload
    def controllerParam_Kp(self) -> float: ...
    @overload
    def controllerParam_Kp() -> double: ...
    @overload
    def controllerParam_Kp(self, v: float) -> None: ...
    @overload
    def controllerParam_Kp(double) -> void: ...
    @overload
    def controllerParam_Ti(self) -> float: ...
    @overload
    def controllerParam_Ti() -> double: ...
    @overload
    def controllerParam_Ti(self, v: float) -> None: ...
    @overload
    def controllerParam_Ti(double) -> void: ...
    @overload
    def estimatedRate(self) -> float: ...
    @overload
    def estimatedRate() -> double: ...
    @overload
    def estimatedRateRaw(self) -> float: ...
    @overload
    def estimatedRateRaw() -> double: ...
    @overload
    def followErrorRatioToRaiseWarning(self) -> float: ...
    @overload
    def followErrorRatioToRaiseWarning() -> double: ...
    @overload
    def followErrorRatioToRaiseWarning(self, v: float) -> None: ...
    @overload
    def followErrorRatioToRaiseWarning(double) -> void: ...
    @overload
    def lowPassParam_a0(self) -> float: ...
    @overload
    def lowPassParam_a0() -> double: ...
    @overload
    def lowPassParam_a0(self, v: float) -> None: ...
    @overload
    def lowPassParam_a0(double) -> void: ...
    @overload
    def setRate(self, rate_hz: float) -> None: ...
    @overload
    def setRate(constdouble) -> void: ...
    @overload
    def sleep(self) -> bool: ...
    @overload
    def sleep() -> bool: ...

class CDirectoryExplorer:
    class TFileInfo:
        accessTime: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t
        fileSize: int
        isDir: bool
        isSymLink: bool
        modTime: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t
        name: str
        wholePath: str
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CDirectoryExplorer.TFileInfo) -> None: ...
        def assign(self) -> CDirectoryExplorer.TFileInfo: ...
    def __init__(self) -> None: ...
    def explore(self, *args, **kwargs) -> Any: ...
    def filterByExtension(self, *args, **kwargs) -> Any: ...
    def sortByName(self, *args, **kwargs) -> Any: ...

class CFileSystemWatcher:
    class TFileSystemChange:
        eventAccessed: bool
        eventCloseWrite: bool
        eventCreated: bool
        eventDeleted: bool
        eventModified: bool
        eventMovedFrom: bool
        eventMovedTo: bool
        isDir: bool
        path: str
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CFileSystemWatcher.TFileSystemChange) -> None: ...
        def assign(self) -> CFileSystemWatcher.TFileSystemChange: ...
    @overload
    def __init__(self, path: str) -> None: ...
    @overload
    def __init__(self, arg0: CFileSystemWatcher) -> None: ...
    def assign(self) -> CFileSystemWatcher: ...

class CObservable:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CObservable) -> None: ...
    def assign(self) -> CObservable: ...

class CObserver:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CObserver) -> None: ...
    def assign(self) -> CObserver: ...
    @overload
    def observeBegin(self, obj: CObservable) -> None: ...
    @overload
    def observeBegin(classmrpt) -> void: ...
    def observeEnd(self, obj: CObservable) -> None: ...

class COutputLoggerStreamWrapper:
    def __init__(self, *args, **kwargs) -> None: ...

class CRateTimer:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, rate_hz: float) -> None: ...
    @overload
    def __init__(self, arg0: CRateTimer) -> None: ...
    def assign(self) -> CRateTimer: ...
    @overload
    def rate(self) -> float: ...
    @overload
    def rate(Hz) -> Any: ...
    @overload
    def rate() -> double: ...
    @overload
    def setRate(self, rate_hz: float) -> None: ...
    @overload
    def setRate(constdouble) -> void: ...
    @overload
    def sleep(self) -> bool: ...
    @overload
    def sleep() -> bool: ...

class CTicTac:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CTicTac) -> None: ...
    @overload
    def Tac(self) -> float: ...
    @overload
    def Tac() -> double: ...
    @overload
    def Tic(self) -> None: ...
    @overload
    def Tic() -> void: ...
    def assign(self) -> CTicTac: ...

class CTimeLogger:
    class TCallStats:
        last_t: float
        max_t: float
        mean_t: float
        min_t: float
        n_calls: int
        total_t: float
        def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, enabled: bool) -> None: ...
    @overload
    def __init__(self, enabled: bool, name: str) -> None: ...
    @overload
    def __init__(self, enabled: bool, name: str, keep_whole_history: bool) -> None: ...
    @overload
    def __init__(self, arg0: CTimeLogger) -> None: ...
    def assign(self, o: CTimeLogger) -> CTimeLogger: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear(self, deep_clear: bool) -> None: ...
    @overload
    def clear() -> Any: ...
    @overload
    def clear(bool) -> void: ...
    @overload
    def disable(self) -> None: ...
    @overload
    def disable() -> void: ...
    @overload
    def dumpAllStats(self) -> None: ...
    @overload
    def dumpAllStats(self, column_width: int) -> None: ...
    @overload
    def dumpAllStats(size_t) -> void: ...
    @overload
    def enable(self) -> None: ...
    @overload
    def enable(self, enabled: bool) -> None: ...
    @overload
    def enable(bool) -> void: ...
    @overload
    def enableKeepWholeHistory(self) -> None: ...
    @overload
    def enableKeepWholeHistory(self, enable: bool) -> None: ...
    @overload
    def enableKeepWholeHistory(bool) -> void: ...
    @overload
    def getLastTime(self, name: str) -> float: ...
    @overload
    def getLastTime(conststd) -> double: ...
    @overload
    def getMeanTime(self, name: str) -> float: ...
    @overload
    def getMeanTime(conststd) -> double: ...
    def getName(self) -> str: ...
    @overload
    def getStatsAsText(self) -> str: ...
    @overload
    def getStatsAsText(self, column_width: int) -> str: ...
    @overload
    def isEnabled(self) -> bool: ...
    @overload
    def isEnabled() -> bool: ...
    @overload
    def isEnabledKeepWholeHistory(self) -> bool: ...
    @overload
    def isEnabledKeepWholeHistory() -> bool: ...
    @overload
    def saveToCSVFile(self, csv_file: str) -> None: ...
    @overload
    def saveToCSVFile(conststd) -> void: ...
    @overload
    def saveToMFile(self, m_file: str) -> None: ...
    @overload
    def saveToMFile(conststd) -> void: ...
    @overload
    def setName(self, name: str) -> None: ...
    @overload
    def setName(conststd) -> void: ...

class CTimeLoggerEntry:
    def __init__(self, arg0: CTimeLoggerEntry) -> None: ...
    @overload
    def stop(self) -> None: ...
    @overload
    def stop() -> void: ...

class CTimeLoggerSaveAtDtor:
    def __init__(self, tm: CTimeLogger) -> None: ...

class ConsoleBackgroundColor:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    BLACK: ClassVar[ConsoleBackgroundColor] = ...
    BLUE: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_BLACK: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_BLUE: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_CYAN: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_GREEN: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_MAGENTA: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_RED: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_WHITE: ClassVar[ConsoleBackgroundColor] = ...
    BRIGHT_YELLOW: ClassVar[ConsoleBackgroundColor] = ...
    CYAN: ClassVar[ConsoleBackgroundColor] = ...
    DEFAULT: ClassVar[ConsoleBackgroundColor] = ...
    GREEN: ClassVar[ConsoleBackgroundColor] = ...
    MAGENTA: ClassVar[ConsoleBackgroundColor] = ...
    RED: ClassVar[ConsoleBackgroundColor] = ...
    WHITE: ClassVar[ConsoleBackgroundColor] = ...
    YELLOW: ClassVar[ConsoleBackgroundColor] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ConsoleForegroundColor:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    BLACK: ClassVar[ConsoleForegroundColor] = ...
    BLUE: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_BLACK: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_BLUE: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_CYAN: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_GREEN: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_MAGENTA: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_RED: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_WHITE: ClassVar[ConsoleForegroundColor] = ...
    BRIGHT_YELLOW: ClassVar[ConsoleForegroundColor] = ...
    CYAN: ClassVar[ConsoleForegroundColor] = ...
    DEFAULT: ClassVar[ConsoleForegroundColor] = ...
    GREEN: ClassVar[ConsoleForegroundColor] = ...
    MAGENTA: ClassVar[ConsoleForegroundColor] = ...
    RED: ClassVar[ConsoleForegroundColor] = ...
    WHITE: ClassVar[ConsoleForegroundColor] = ...
    YELLOW: ClassVar[ConsoleForegroundColor] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ConsoleTextStyle:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    BLINKING: ClassVar[ConsoleTextStyle] = ...
    BOLD: ClassVar[ConsoleTextStyle] = ...
    DIM: ClassVar[ConsoleTextStyle] = ...
    INVISIBLE: ClassVar[ConsoleTextStyle] = ...
    ITALIC: ClassVar[ConsoleTextStyle] = ...
    REGULAR: ClassVar[ConsoleTextStyle] = ...
    REVERSE: ClassVar[ConsoleTextStyle] = ...
    UNDERLINED: ClassVar[ConsoleTextStyle] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TProcessPriority:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    ppHigh: ClassVar[TProcessPriority] = ...
    ppIdle: ClassVar[TProcessPriority] = ...
    ppNormal: ClassVar[TProcessPriority] = ...
    ppVeryHigh: ClassVar[TProcessPriority] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TThreadPriority:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    tpHigh: ClassVar[TThreadPriority] = ...
    tpHigher: ClassVar[TThreadPriority] = ...
    tpHighest: ClassVar[TThreadPriority] = ...
    tpLow: ClassVar[TThreadPriority] = ...
    tpLower: ClassVar[TThreadPriority] = ...
    tpLowests: ClassVar[TThreadPriority] = ...
    tpNormal: ClassVar[TThreadPriority] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TTimeParts:
    day: int
    day_of_week: int
    daylight_saving: int
    hour: int
    minute: int
    month: int
    second: float
    year: int
    def __init__(self) -> None: ...

class VerbosityLevel:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    LVL_DEBUG: ClassVar[VerbosityLevel] = ...
    LVL_ERROR: ClassVar[VerbosityLevel] = ...
    LVL_INFO: ClassVar[VerbosityLevel] = ...
    LVL_WARN: ClassVar[VerbosityLevel] = ...
    NUMBER_OF_VERBOSITY_LEVELS: ClassVar[VerbosityLevel] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class WorkerThreadsPool:
    class queue_policy_t:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        POLICY_DROP_OLD: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
        POLICY_FIFO: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    POLICY_DROP_OLD: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
    POLICY_FIFO: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, num_threads: int) -> None: ...
    @overload
    def __init__(self, num_threads: int, p) -> None: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def pendingTasks(self) -> int: ...
    @overload
    def resize(self, num_threads: int) -> None: ...
    @overload
    def resize(std) -> void: ...

class mrptEvent:
    timestamp: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: mrptEvent) -> None: ...
    @overload
    def __init__(self, arg0: mrptEvent) -> None: ...
    def assign(self) -> mrptEvent: ...

class mrptEventOnDestroy(mrptEvent):
    def __init__(self, obj) -> None: ...
    def assign(self) -> mrptEventOnDestroy: ...

def InvalidTimeStamp() -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
def MRPT_getCompilationDate() -> str: ...
def MRPT_getVersion() -> str: ...
def buildTimestampFromParts(p: TTimeParts) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
def buildTimestampFromPartsLocalTime(p: TTimeParts) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
def changeCurrentProcessPriority(*args, **kwargs) -> Any: ...
@overload
def changeCurrentThreadPriority(priority: TThreadPriority) -> None: ...
@overload
def changeCurrentThreadPriority(enummrpt) -> void: ...
@overload
def clearConsole() -> None: ...
@overload
def clearConsole() -> void: ...
@overload
def compute_CRC16(data: int, len: int) -> int: ...
@overload
def compute_CRC16(data: int, len: int, gen_pol: int) -> int: ...
@overload
def compute_CRC32(data: int, len: int) -> int: ...
@overload
def compute_CRC32(data: int, len: int, gen_pol: int) -> int: ...
@overload
def consoleColorAndStyle(fg: ConsoleForegroundColor) -> None: ...
@overload
def consoleColorAndStyle(fg: ConsoleForegroundColor, bg: ConsoleBackgroundColor) -> None: ...
@overload
def consoleColorAndStyle(fg: ConsoleForegroundColor, bg: ConsoleBackgroundColor, style: ConsoleTextStyle) -> None: ...
@overload
def consoleColorAndStyle(fg: ConsoleForegroundColor, bg: ConsoleBackgroundColor, style: ConsoleTextStyle, applyToStdErr: bool) -> None: ...
@overload
def copyFile(sourceFile: str, targetFile: str) -> bool: ...
@overload
def copyFile(sourceFile: str, targetFile: str, outErrStr: str) -> bool: ...
@overload
def createDirectory(dirName: str) -> bool: ...
@overload
def createDirectory(conststd) -> bool: ...
def dateTimeLocalToString(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> str: ...
def dateTimeToString(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> str: ...
def dateToString(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> str: ...
@overload
def deleteFile(fileName: str) -> bool: ...
@overload
def deleteFile(conststd) -> bool: ...
@overload
def deleteFiles(s: str) -> None: ...
@overload
def deleteFiles(conststd) -> void: ...
@overload
def deleteFilesInDirectory(s: str) -> bool: ...
@overload
def deleteFilesInDirectory(s: str, deleteDirectoryAsWell: bool) -> bool: ...
@overload
def deleteFilesInDirectory(conststd, bool) -> bool: ...
@overload
def directoryExists(fileName: str) -> bool: ...
@overload
def directoryExists(conststd) -> bool: ...
@overload
def executeCommand(command: str) -> int: ...
@overload
def executeCommand(command: str, output: str) -> int: ...
@overload
def executeCommand(command: str, output: str, mode: str) -> int: ...
@overload
def extractDayTimeFromTimestamp(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> float: ...
@overload
def extractDayTimeFromTimestamp(constmrpt) -> double: ...
def extractFileDirectory(filePath: str) -> str: ...
def extractFileExtension(*args, **kwargs) -> Any: ...
def extractFileName(filePath: str) -> str: ...
@overload
def fileExists(fileName: str) -> bool: ...
@overload
def fileExists(conststd) -> bool: ...
def fileNameChangeExtension(filename: str, newExtension: str) -> str: ...
@overload
def fileNameStripInvalidChars(filename: str) -> str: ...
@overload
def fileNameStripInvalidChars(filename: str, replacement_to_invalid_chars: str) -> str: ...
def filePathSeparatorsToNative(filePath: str) -> str: ...
def find_mrpt_shared_dir() -> str: ...
def firstNLines(str: str, n: int) -> str: ...
def formatTimeInterval(timeSeconds: float) -> str: ...
def getFileModificationTime(filename: str) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
@overload
def getFileSize(fileName: str) -> int: ...
@overload
def getFileSize(conststd) -> uint64_t: ...
def getMRPTLicense() -> str: ...
@overload
def getMemoryUsage() -> int: ...
@overload
def getMemoryUsage() -> unsignedlong: ...
def getShareMRPTDir() -> str: ...
def getTempFileName() -> str: ...
def getcwd() -> str: ...
def global_profiler_enter(func_name: str) -> None: ...
def global_profiler_getref() -> CTimeLogger: ...
def global_profiler_leave(func_name: str) -> None: ...
def intervalFormat(seconds: float) -> str: ...
@overload
def launchProcess(command: str) -> bool: ...
@overload
def launchProcess(conststd) -> bool: ...
def lowerCase(str: str) -> str: ...
def md5(str: str) -> str: ...
def nthOccurrence(str: str, strToFind: str, nth: int) -> int: ...
def pathJoin(paths: List[str]) -> str: ...
@overload
def pause() -> None: ...
@overload
def pause(msg: str) -> None: ...
@overload
def pause(conststd) -> void: ...
@overload
def progress(progressRatio0to1: float, barLength: int) -> str: ...
@overload
def progress(progressRatio0to1: float, barLength: int, encloseInSquareBrackets: bool) -> str: ...
@overload
def renameFile(oldFileName: str, newFileName: str) -> bool: ...
@overload
def renameFile(oldFileName: str, newFileName: str, error_msg: str) -> bool: ...
@overload
def rightPad(str: str, total_len: int) -> str: ...
@overload
def rightPad(str: str, total_len: int, truncate_if_larger: bool) -> str: ...
def strCmp(s1: str, s2: str) -> bool: ...
def strCmpI(s1: str, s2: str) -> bool: ...
def strStarts(str: str, subStr: str) -> bool: ...
def strStartsI(str: str, subStr: str) -> bool: ...
@overload
def stringListAsString(lst: List[str], out: str) -> None: ...
@overload
def stringListAsString(lst: List[str], out: str, newline: str) -> None: ...
@overload
def stringListAsString(constclassstd, std, conststd) -> void: ...
@overload
def thread_name(name: str) -> None: ...
@overload
def thread_name(conststd) -> void: ...
@overload
def thread_name() -> str: ...
def timeDifference(t_first: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t, t_later: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> float: ...
@overload
def timeLocalToString(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> str: ...
@overload
def timeLocalToString(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t, secondFractionDigits: int) -> str: ...
def timeToString(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> str: ...
def timestampAdd(tim: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t, num_seconds: float) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
@overload
def timestampToParts(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t, p: TTimeParts) -> None: ...
@overload
def timestampToParts(t: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t, p: TTimeParts, localTime: bool) -> None: ...
@overload
def timestampToParts(mrpt, structmrpt, bool) -> void: ...
@overload
def toAbsolutePath(path: str) -> str: ...
@overload
def toAbsolutePath(path: str, resolveToCanonical: bool) -> str: ...
@overload
def tokenize(inString: str, inDelimiters: str, outTokens: List[str]) -> None: ...
@overload
def tokenize(inString: str, inDelimiters: str, outTokens: List[str], skipBlankTokens: bool) -> None: ...
def trim(str: str) -> str: ...
@overload
def unitsFormat(val: float) -> str: ...
@overload
def unitsFormat(val: float, nDecimalDigits: int) -> str: ...
@overload
def unitsFormat(val: float, nDecimalDigits: int, middle_space: bool) -> str: ...
def upperCase(str: str) -> str: ...



from typing import Any

from typing import overload
import mrpt.pymrpt.mrpt

class CLASS_ID_impl_mrpt_maps_CBeaconMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CColouredOctoMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CColouredPointsMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CGasConcentrationGridMap2D_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CHeightGridMap2D_MRF_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CHeightGridMap2D_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CLandmarksMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_COccupancyGridMap2D_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_COccupancyGridMap3D_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_COctoMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CPointsMapXYZI_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CReflectivityGridMap2D_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CSimplePointsMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CVoxelMapRGB_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CVoxelMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CWeightedPointsMap_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_maps_CWirelessPowerGridMap2D_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_obs_CObservation_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_obs_CSensoryFrame_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CLASS_ID_impl_mrpt_rtti_CObject_t:
    def __init__(self) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...

class CListOfClasses(mrpt.pymrpt.mrpt.Stringifyable):
    data: Set[TRuntimeClassId]
    @overload
    def __init__(self, arg0: CListOfClasses) -> None: ...
    @overload
    def __init__(self, arg0: CListOfClasses) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def asString(self) -> str: ...
    def assign(self) -> CListOfClasses: ...
    @overload
    def contains(self, id: TRuntimeClassId) -> bool: ...
    @overload
    def contains(conststructmrpt) -> bool: ...
    @overload
    def containsDerivedFrom(self, id: TRuntimeClassId) -> bool: ...
    @overload
    def containsDerivedFrom(conststructmrpt) -> bool: ...
    @overload
    def fromString(self, s: str) -> None: ...
    @overload
    def fromString(conststd) -> void: ...
    @overload
    def insert(self, id: TRuntimeClassId) -> None: ...
    @overload
    def insert(conststructmrpt) -> void: ...

class CObject:
    @overload
    def __init__(self, arg0: CObject) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def GetRuntimeClass(self) -> TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def assign(self) -> CObject: ...
    def clone(self) -> CObject: ...
    def duplicateGetSmartPtr(self) -> CObject: ...

class TRuntimeClassId:
    def __init__(self) -> None: ...
    def createObject(self, *args, **kwargs) -> Any: ...
    @overload
    def derivedFrom(self, pBaseClass: TRuntimeClassId) -> bool: ...
    @overload
    def derivedFrom(conststructmrpt) -> bool: ...
    @overload
    def derivedFrom(self, pBaseClass_name: str) -> bool: ...

def classFactory(className: str) -> CObject: ...
@overload
def findRegisteredClass(className: str) -> TRuntimeClassId: ...
@overload
def findRegisteredClass(className: str, allow_ignore_namespace: bool) -> TRuntimeClassId: ...
@overload
def registerAllPendingClasses() -> None: ...
@overload
def registerAllPendingClasses() -> void: ...
def registerClass(*args, **kwargs) -> Any: ...
def registerClassCustomName(customName: str, pNewClass: TRuntimeClassId) -> None: ...
